@@ -105,7 +105,8 @@ default_muse_unit = u.erg / (u.cm * u.cm * u.second * u.AA) * 1.e-20
 default_reference_unit = u.microJansky
 
 dict_equivalencies = {"WFI_BB": u.spectral_density(6483.58 * u.AA),
-                      "DUPONT_R": u.spectral_density(6483.58 * u.AA)}
+                      "DUPONT_R": u.spectral_density(6483.58 * u.AA),
+                      "Legacy_r": u.spectral_density(6483.58 * u.AA)}
 # ================== Useful function ====================== #
 
 
@@ -520,6 +521,9 @@ class AlignMuseDataset(object):
             Suffix to be used for muse image names if only a subset should be selected.
         filter_name: str
             Name of filter to consider when filtering the muse image names
+        filter_suffix: str
+            String defined to filter the image names. If not provided, will be defaulted
+            to the provided filter_name.
         firstguess: str
             If "crosscorr", will use cross-correlation to guess the alignment offsets.
             If "fits", will use input fits OFFSET table to start with
@@ -639,6 +643,7 @@ class AlignMuseDataset(object):
         self.name_offmusehdr = kwargs.pop("name_offmusehdr", "offsetmuse")
         self.suffix_images = kwargs.pop("suffix_muse_images", "IMAGE_FOV")
         self.filter_name = kwargs.pop("filter_name", "Cousins_R")
+        self.filter_suffix = kwargs.pop("filter_suffix", self.filter_name)
 
         # Use polynorm or not
         self.use_polynorm = kwargs.pop("use_polynorm", True)
@@ -1188,7 +1193,7 @@ class AlignMuseDataset(object):
         if self.name_muse_images is None:
             set_of_paths = glob.glob("{0}*{1}*.fits".format(
                 joinpath(self.folder_muse_images,
-                         self.suffix_images), self.filter_name))
+                         self.suffix_images), self.filter_suffix))
             self.list_name_museimages = [Path(muse_path).name
                                          for muse_path in set_of_paths]
             # Sort alphabetically
@@ -1329,6 +1334,8 @@ class AlignMuseDataset(object):
         border = kwargs.pop("border", self.border)
         mask_stars = kwargs.pop("mask_stars", False)
         threshold = kwargs.pop("threshold", self.default_threshold)
+        if threshold is None:
+            threshold = self.default_threshold
 
         # Save hdr if save_hdr is True
         if self.save_hdr:
@@ -1663,7 +1670,6 @@ class AlignMuseDataset(object):
                                                               header=header, verbose=verbose,
                                                               **kwargs)
 
-
     def init_optical_flow_hdu(self, muse_hdu, rotation=0., threshold=None, guess_translation=(0.,0.),
                               header=None, verbose=False, **kwargs):
         """Get the optical flow for this hdu
@@ -1683,7 +1689,7 @@ class AlignMuseDataset(object):
         """
         # Getting the images. Note that border must be 0 as otherwise you will need to change
         # the WCS (header passed to AlignOpticalFlow
-        ima_ref, ima_muse = self.get_imaref_muse(muse_hdu, rotation, threshold, border=0,
+        ima_ref, ima_muse = self.get_imaref_muse(muse_hdu, rotation, threshold=threshold, border=0,
                                                  remove_bkg=False, squeeze=False, **kwargs)
         if self._debug:
             self._temp_input_opflow_muse = ima_muse * 1.0
@@ -1759,7 +1765,7 @@ class AlignMuseDataset(object):
         xpix_cross
         ypix_cross: x and y pixel coordinates of the cross-correlation peak
         """
-        ima_ref, ima_muse = self.get_imaref_muse(muse_hdu, rotation, threshold, **kwargs)
+        ima_ref, ima_muse = self.get_imaref_muse(muse_hdu, rotation, threshold=threshold, **kwargs)
 
         if self.phase_corr:
             shifts, shift_errors, phasediff = phase_cross_correlation(ima_ref, ima_muse,
